==> qt-creator-opensource-src-4.0.2.zip: qt-creator-opensource-src-4.0.2/src/plugins/clangstaticanalyzer/clangstaticanalyzerplugin.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef CLANGSTATICANALYZERPLUGIN_H
#define CLANGSTATICANALYZERPLUGIN_H

#include <extensionsystem/iplugin.h>

namespace ClangStaticAnalyzer {
namespace Internal {

class ClangStaticAnalyzerTool;
class ClangStaticAnalyzerSettings;

class ClangStaticAnalyzerPlugin : public ExtensionSystem::IPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "ClangStaticAnalyzer.json")

public:
    ClangStaticAnalyzerPlugin();
    ~ClangStaticAnalyzerPlugin();

    bool initialize(const QStringList &arguments, QString *errorString);
    bool initializeEnterpriseFeatures(const QStringList &arguments, QString *errorString);
    void extensionsInitialized();
    ShutdownFlag aboutToShutdown();

private:
    QList<QObject *> createTestObjects() const;

    ClangStaticAnalyzerTool *m_analyzerTool;
};

} // namespace Internal
} // namespace ClangStaticAnalyzerPlugin

#endif // CLANGSTATICANALYZERPLUGIN_H

==> qt-creator-opensource-src-4.3.1.zip: qt-creator-opensource-src-4.3.1/src/plugins/clangstaticanalyzer/clangstaticanalyzerplugin.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include <extensionsystem/iplugin.h>

namespace ClangStaticAnalyzer {
namespace Internal {

class ClangStaticAnalyzerTool;
class ClangStaticAnalyzerSettings;

class ClangStaticAnalyzerPlugin : public ExtensionSystem::IPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QtCreatorPlugin" FILE "ClangStaticAnalyzer.json")

public:
    ClangStaticAnalyzerPlugin();
    ~ClangStaticAnalyzerPlugin();

    bool initialize(const QStringList &arguments, QString *errorString);
    bool initializeEnterpriseFeatures(const QStringList &arguments, QString *errorString);
    void extensionsInitialized();
    ShutdownFlag aboutToShutdown();

private:
    QList<QObject *> createTestObjects() const;

    ClangStaticAnalyzerTool *m_analyzerTool;
};

} // namespace Internal
} // namespace ClangStaticAnalyzerPlugin
